"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const getStoreValue = (key, localStorage, initialValue) => {
    if (localStorage && key in localStorage) {
        return localStorage[key];
    }
    try {
        const item = window.localStorage.getItem(key);
        return item ? JSON.parse(item) : initialValue;
    }
    catch (error) {
        console.log(error);
        return initialValue;
    }
};
const useLocalStorage = (key, initialValue, options) => {
    const storedValue = getStoreValue(key, options === null || options === void 0 ? void 0 : options.storage, initialValue);
    const setValue = react_1.useCallback((value) => {
        var _a;
        (_a = options === null || options === void 0 ? void 0 : options.onChanged) === null || _a === void 0 ? void 0 : _a.call(options, key, value);
        window.localStorage.setItem(key, JSON.stringify(value));
    }, [storedValue]);
    return [storedValue, setValue];
};
exports.default = useLocalStorage;
//# sourceMappingURL=index.js.map